Web Navigation
--------------

JavaScript helpers for responsive navigation menus.

``web.nav`` accepts a ``--style`` parameter during setup to select the
initial theme without exposing the style switcher. Use ``--style random``
to pick a random theme on each request.
The style switcher drop-down also includes a **Random** option to toggle
this behavior per user.
